package com.fs.course.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.course.domain.FsCourseFinishTempParent;

import java.util.List;

/**
 * 完课模板Service接口
 * 
 * @author 吴树波
 * @date 2025-05-22
 */
public interface IFsCourseFinishTempParentService extends IService<FsCourseFinishTempParent>{
    /**
     * 查询完课模板
     * 
     * @param id 完课模板主键
     * @return 完课模板
     */
    FsCourseFinishTempParent selectFsCourseFinishTempParentById(Long id);

    /**
     * 查询完课模板列表
     * 
     * @param fsCourseFinishTempParent 完课模板
     * @return 完课模板集合
     */
    List<FsCourseFinishTempParent> selectFsCourseFinishTempParentList(FsCourseFinishTempParent fsCourseFinishTempParent);

    /**
     * 新增完课模板
     * 
     * @param fsCourseFinishTempParent 完课模板
     * @return 结果
     */
    int insertFsCourseFinishTempParent(FsCourseFinishTempParent fsCourseFinishTempParent);

    /**
     * 修改完课模板
     * 
     * @param fsCourseFinishTempParent 完课模板
     * @return 结果
     */
    int updateFsCourseFinishTempParent(FsCourseFinishTempParent fsCourseFinishTempParent);

    /**
     * 批量删除完课模板
     * 
     * @param ids 需要删除的完课模板主键集合
     * @return 结果
     */
    int deleteFsCourseFinishTempParentByIds(Long[] ids);

    /**
     * 删除完课模板信息
     * 
     * @param id 完课模板主键
     * @return 结果
     */
    int deleteFsCourseFinishTempParentById(Long id);
}
